@@ -1,5 +1,5 @@
 import logging
 
 # Prevents logging output in tests
-log = logging.getLogger('nbxmpp')
+log = logging.getLogger("nbxmpp")
 log.setLevel(logging.CRITICAL)
